@@ -202,10 +202,23 @@ def freehub_cat(address:str,**kwargs):
     cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True,**kwargs)
     file_path = join_path(cache_dir, relative_path)
     with open(file_path,'r') as f:
-        print(address.center(100,'*'))
         print(f.read())
-        print(('End of %s'%(address)).center(100, '*'))
+def freehub_update():
+    cache_dir=join_path(STORE_HOME,'freehub')
+    if os.path.exists(cache_dir):
+        shutil.rmtree(cache_dir)
+        time.sleep(1e-10)
+    freehub_download('gitee.com/peiiii/gitspace:freehub',cache_dir)
+    dist_dir=join_path(cache_dir,'dist')
+    files=glob.glob(dist_dir+'/*.whl')
+    print('Files to install:',files)
+    for f in files:
+        if f.endswith('.whl'):
+            os.system('pip3 install %s'%(f))
+    if not files:
+        logging.warning('Noting to install')
 
+    # cache_dir=freehub_download('gitee.com/')
 def freehub_search(pattern: str,**kwargs):
     '''
     :param reg_str: [[{host}/]{username}/]{repo_name}[:{branch_name}]
