@@ -3,6 +3,7 @@ import os
 os.environ['ANSI_COLORS_DISABLED']="1"
 import shutil
 import fire
+from freehub import utils
 
 class Cli:
     '''
@@ -26,6 +27,9 @@ class Cli:
     def publish(cls,address,str):
         raise NotImplementedError(cls.publish)
     @classmethod
+    def update(cls):
+        apis.freehub_update()
+    @classmethod
     def download(cls,address,path=None,overwrite=False):
         path=path or './'
         address=apis.get_complete_address(address)
@@ -87,6 +91,25 @@ class Cli:
             kwargs_string.append('--%s=%s' % (k, v))
         kwargs_string = ' '.join(kwargs_string)
         os.system('%s %s %s'%(script_path,args_string,kwargs_string))
+
+    @classmethod
+    def shrun(cls, address: str, *args, **kwargs):
+        address = apis.get_complete_address(address)
+        script_path = apis.fetch(address)
+        def try_file_path(pre, sufs=None):
+            if sufs is None:
+                sufs = []
+            sufs=['']+sufs
+            for suf in sufs:
+                if os.path.exists(pre+suf):
+                    return pre+suf
+        script_path=try_file_path(script_path,['.sh'])
+        args_string = ' '.join(args)
+        kwargs_string = []
+        for k, v in kwargs.items():
+            kwargs_string.append('--%s=%s' % (k, v))
+        kwargs_string = ' '.join(kwargs_string)
+        os.system('bash %s %s %s' % (script_path, args_string, kwargs_string))
     @classmethod
     def test(cls,*args,**kwargs):
         print(*args)
